@@ -166,7 +166,7 @@ class Cryptomatte(object):
         annotations = [annotation for annotation in annotations if "contours" not in annotation]
 
         for instance in self.instances:
-            category, index = instance.split("/")
+            category, index = instance.rsplit("/", 1)
 
             contours = self.contours(instance)
             if contours:
@@ -181,8 +181,6 @@ class Cryptomatte(object):
                     "bbox": self.bbox(instance),
                     "bbox_mode": "XYWH_ABS",
                 })
-        #import pprint
-        #pprint.pprint(annotations)
         self._sample.update_metadata({"annotations": annotations})
 
 
@@ -242,7 +240,7 @@ class Cryptomatte(object):
         colors = {}
         categories = {}
         for instance in self.instances:
-            category, index = instance.split("/")
+            category, index = instance.rsplit("/", 1)
             if category not in categories:
                 categories[category] = next(color)
             colors[instance] = categories[category]
@@ -494,6 +492,35 @@ class Sample(object):
         return {annotation["category"] for annotation in self._metadata.get("annotations", [])}
 
 
+    @property
+    def default_cryptomatte_path(self):
+        image_filename = self.name.replace("image", "cryptomatte") + ".cryptomatte.exr"
+        image_path = os.path.join(os.path.dirname(self.path), image_filename)
+        return image_path
+
+
+    @property
+    def default_image_path(self):
+        image_filename = self.name + ".png"
+        image_path = os.path.join(os.path.dirname(self.path), image_filename)
+        return image_path
+
+
+    @property
+    def default_synthetic_path(self):
+        image_filename = self.name + ".exr"
+        image_path = os.path.join(os.path.dirname(self.path), image_filename)
+        return image_path
+
+
+    def delete(self):
+        """Unconditionally remove this sample and related files."""
+        paths = [self.default_cryptomatte_path, self.default_image_path, self.default_synthetic_path, self.path]
+        for path in paths:
+            if os.path.exists(path):
+                os.remove(path)
+
+
     @property
     def graph(self):
         """Graphcat network used for image processing.
